/** Api 类型错误 */
export declare class ApiTypeError extends Error {
    /** 错误类型 */
    type: string;
    /** 错误堆栈信息 */
    stack?: string;
    /** 请求 ID */
    reqId?: string;
    /** 展示信息 */
    displayMsg: string;
    /**
     * 构造函数
     *
     * @param type 错误类型
     * @param msg 错误信息
     * @param stack 错误栈信息
     * @param reqId 请求 id
     * @param displayMsg 展示信息
     * @returns 构造的错误对象
     */
    constructor(type: string, msg: string, stack?: string, reqId?: string, displayMsg?: string);
}
/** Api 类型错误构造函数参数 */
interface ApiErrorOptions {
    /** 错误信息 */
    message: string;
    /** 栈信息 */
    stack?: string;
    /** 错误类型 */
    type: string;
    /** 请求 Id */
    reqId?: string;
    /** 错误码 */
    code?: string;
    /** 展示信息，不填则为 message */
    displayMsg?: string;
}
/** Api 调用错误 */
export declare class ApiError extends Error {
    /** 错误类型 */
    type: string;
    /** 请求 ID */
    reqId?: string;
    /** 请求错误码 */
    code?: string;
    /** 展示信息 */
    displayMsg: string;
    /**
     * 构造函数
     *
     * @param options 构造请求的参数
     */
    constructor(options: ApiErrorOptions);
}
export {};
