"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiError = exports.ApiTypeError = void 0;
/** Api 类型错误 */
class ApiTypeError extends Error {
    /**
     * 构造函数
     *
     * @param type 错误类型
     * @param msg 错误信息
     * @param stack 错误栈信息
     * @param reqId 请求 id
     * @param displayMsg 展示信息
     * @returns 构造的错误对象
     */
    constructor(type, msg, stack, reqId, displayMsg) {
        super(msg);
        this.type = type;
        this.displayMsg = displayMsg !== null && displayMsg !== void 0 ? displayMsg : msg;
        if (stack) {
            this.stack = stack;
        }
        if (reqId) {
            this.reqId = reqId;
        }
    }
}
exports.ApiTypeError = ApiTypeError;
/** Api 调用错误 */
class ApiError extends Error {
    /**
     * 构造函数
     *
     * @param options 构造请求的参数
     */
    constructor(options) {
        const { type, message, stack, reqId, displayMsg, code } = options;
        super(message);
        this.type = type;
        if (stack) {
            this.stack = stack;
        }
        if (reqId) {
            this.reqId = reqId;
        }
        if (code) {
            this.code = code;
        }
        this.displayMsg = displayMsg !== null && displayMsg !== void 0 ? displayMsg : message;
        return this;
    }
}
exports.ApiError = ApiError;
