"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deepClone = exports.removeUndefined = exports.pascalCaseProperty = exports.pascalCase = void 0;
const _ = require("lodash");
/**
 * 将字符串转为大驼峰
 *
 * @param str 要转换的字符串
 * @returns 转换完的字符串
 */
function pascalCase(str) {
    return _.startCase(_.camelCase(str)).replace(/ /g, '');
}
exports.pascalCase = pascalCase;
/**
 * 将 object 深层的转为大驼峰
 *
 * @param obj 要转换的对象
 * @returns 转换的结果
 */
function pascalCaseProperty(obj) {
    let res = {};
    if (_.isObject(obj)) {
        res = {};
        Object.keys(obj).forEach((key) => {
            const val = obj[key];
            const k = pascalCase(key);
            res[k] = _.isObject(val) || _.isArray(val) ? pascalCaseProperty(val) : val;
        });
    }
    if (_.isArray(obj)) {
        res = [];
        obj.forEach((item) => {
            res.push(_.isObject(item) || _.isArray(item) ? pascalCaseProperty(item) : item);
        });
    }
    return res;
}
exports.pascalCaseProperty = pascalCaseProperty;
/**
 * 深层的移除对象中的 undefined（只支持 plain object）
 *
 * @param obj 要移除 undefined 的对象
 * @returns 移除完的结果
 */
function removeUndefined(obj) {
    return JSON.parse(JSON.stringify(obj));
}
exports.removeUndefined = removeUndefined;
/**
 * 深拷贝对象（只支持 plain object）
 *
 * @param obj 要深拷贝的对象
 * @returns 拷贝完成的结果
 */
function deepClone(obj) {
    return JSON.parse(JSON.stringify(obj));
}
exports.deepClone = deepClone;
