import { ApiError, ApiTypeError } from '../src/error';
import { pascalCase, pascalCaseProperty, removeUndefined, deepClone } from '../src';

describe('Common', () => {
  test('ApiError', () => {
    const obj = {
      type: 'test_type',
      message: 'test_message',
      stack: 'test_stack',
      reqId: 'test_id',
      code: 'test_code',
      displayMsg: 'test_displayMsg',
    };
    const err = new ApiError(obj);
    expect(err).toBeInstanceOf(Error);
    expect(err).toMatchObject(obj);
  });

  test('ApiTypeError', () => {
    const obj = {
      type: 'test_type',
      message: 'test_message',
      stack: 'test_stack',
      reqId: 'test_id',
      displayMsg: 'test_displayMsg',
    };
    const err = new ApiTypeError(obj.type, obj.message, obj.stack, obj.reqId, obj.displayMsg);
    expect(err).toBeInstanceOf(Error);
    expect(err).toMatchObject(obj);
  });

  test('pascalCase', () => {
    expect(pascalCase('helloWorld')).toBe('HelloWorld');
    expect(pascalCase('hello_World')).toBe('HelloWorld');

    expect(pascalCase('hello_world_my_friend')).toBe('HelloWorldMyFriend');
  });

  test('pascalCaseProps', () => {
    expect(
      pascalCaseProperty({
        hello: 'hello',
        world: 'world',
        deep: {
          deep: 'deep',
          array: [
            {
              deepArray: [{ a: '' }],
            },
          ],
        },
      }),
    ).toEqual({
      Hello: 'hello',
      World: 'world',
      Deep: {
        Deep: 'deep',
        Array: [
          {
            DeepArray: [{ A: '' }],
          },
        ],
      },
    });
  });

  test('deepClone', () => {
    const o = { a: { b: { c: { d: 'e' } } } };
    const cloneO = deepClone(o);
    expect(cloneO).not.toBe(o);
    expect(cloneO).toEqual(o);
  });

  test('removeUndefined', () => {
    const o = { a: { b: { c: { d: undefined } } } };
    const removeUndefinedO = removeUndefined(o);
    expect(o.a.b.c.hasOwnProperty('d')).toEqual(true);
    expect(removeUndefinedO.a.b.c.hasOwnProperty('d')).toEqual(false);
  });
});
